pub struct BenchmarkingJobParameters {
pub run_parameters: Arc<RunParameters>,
pub command: Arc<BenchmarkingCommand>,
}Expand description
Only the parts of a BenchmarkingJob that determine results–but also excluding schedule_condition, which does have a conscious influence on results, but comes from the configured pipeline, not the insertion. This here is used for insertion uniqueness checking, but maybe also for key determination lager (XX todo).
Fields
run_parameters: Arc<RunParameters>command: Arc<BenchmarkingCommand>NOTE that BenchmarkingCommand has both target_name and the
actual values; we currently make our key be based on both at
the same time! I.e. a job with the same actual values but
different target_name will be treated as another key!
(FUTURE: is this really right?)
Implementations
Sourceimpl BenchmarkingJobParameters
impl BenchmarkingJobParameters
pub fn slow_hash(&self) -> BenchmarkingJobParametersHash
pub fn to_key_dir(&self, output_base_dir: Arc<Path>) -> Arc<KeyDir>