pub struct BenchmarkingJobParametersHash(/* private fields */);Trait Implementations
Sourceimpl AsKey for BenchmarkingJobParametersHash
impl AsKey for BenchmarkingJobParametersHash
Sourcefn as_filename_str(&self) -> Cow<'_, str>
fn as_filename_str(&self) -> Cow<'_, str>
. (leading dot is used for temporary
files), or contain the / or \0 characters, must be at
least 1 and at most 254 bytes long, and should never contain
control characters (this could make it a pain for people to
use command line tools to work with the databases).Sourcefn try_from_filename_str(file_name: &str) -> Option<Self>
fn try_from_filename_str(file_name: &str) -> Option<Self>
as_filename_str back into a Self
equal to the original self. If not possible (e.g. a human
placed an invalid file), return None.Sourcefn verified_as_filename_str(&self) -> Cow<'_, str>
fn verified_as_filename_str(&self) -> Cow<'_, str>
as_filename_str and asserts that the result complies
to the rules mentioned above, panics if it does not.Sourceimpl Clone for BenchmarkingJobParametersHash
impl Clone for BenchmarkingJobParametersHash
Sourcefn clone(&self) -> BenchmarkingJobParametersHash
fn clone(&self) -> BenchmarkingJobParametersHash
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl<'de> Deserialize<'de> for BenchmarkingJobParametersHash
impl<'de> Deserialize<'de> for BenchmarkingJobParametersHash
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Sourceimpl From<&BenchmarkingJobParameters> for BenchmarkingJobParametersHash
impl From<&BenchmarkingJobParameters> for BenchmarkingJobParametersHash
Sourcefn from(value: &BenchmarkingJobParameters) -> Self
fn from(value: &BenchmarkingJobParameters) -> Self
Sourceimpl Ord for BenchmarkingJobParametersHash
impl Ord for BenchmarkingJobParametersHash
Sourcefn cmp(&self, other: &BenchmarkingJobParametersHash) -> Ordering
fn cmp(&self, other: &BenchmarkingJobParametersHash) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Sourceimpl PartialEq for BenchmarkingJobParametersHash
impl PartialEq for BenchmarkingJobParametersHash
Sourcefn eq(&self, other: &BenchmarkingJobParametersHash) -> bool
fn eq(&self, other: &BenchmarkingJobParametersHash) -> bool
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for BenchmarkingJobParametersHash
impl PartialOrd for BenchmarkingJobParametersHash
impl Eq for BenchmarkingJobParametersHash
impl StructuralPartialEq for BenchmarkingJobParametersHash